
From: Chris Wright <chrisw@osdl.org>

Fixup another round of sparse warnings of the type:
	warning: Using plain integer as NULL pointer
Acked by Stephen.

From: Mika Kukkonen <mika@osdl.org>
Signed-off-by: Chris Wright <chrisw@osdl.org>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/security/selinux/avc.c            |   22 +++++++++++-----------
 25-akpm/security/selinux/ss/conditional.c |    4 ++--
 25-akpm/security/selinux/ss/ebitmap.c     |   12 ++++++------
 25-akpm/security/selinux/ss/mls.c         |    4 ++--
 25-akpm/security/selinux/ss/policydb.c    |   20 ++++++++++----------
 25-akpm/security/selinux/ss/services.c    |    8 ++++----
 6 files changed, 35 insertions(+), 35 deletions(-)

diff -puN security/selinux/avc.c~use-null-instead-of-integer-0-in-security-selinux security/selinux/avc.c
--- 25/security/selinux/avc.c~use-null-instead-of-integer-0-in-security-selinux	2004-07-07 12:29:26.994936160 -0700
+++ 25-akpm/security/selinux/avc.c	2004-07-07 12:29:27.006934336 -0700
@@ -106,7 +106,7 @@ static inline void avc_cache_stats_add(i
  */
 void avc_dump_av(struct audit_buffer *ab, u16 tclass, u32 av)
 {
-	char **common_pts = 0;
+	char **common_pts = NULL;
 	u32 common_base = 0;
 	int i, i2, perm;
 
@@ -734,7 +734,7 @@ static int avc_update_cache(u32 event, u
 		}
 	} else {
 		/* apply to one node */
-		node = avc_search_node(ssid, tsid, tclass, 0);
+		node = avc_search_node(ssid, tsid, tclass, NULL);
 		if (node) {
 			avc_update_node(event,node,perms);
 		}
@@ -808,7 +808,7 @@ int avc_ss_grant(u32 ssid, u32 tsid, u16
                  u32 perms, u32 seqno)
 {
 	return avc_control(AVC_CALLBACK_GRANT,
-			   ssid, tsid, tclass, perms, seqno, 0);
+			   ssid, tsid, tclass, perms, seqno, NULL);
 }
 
 /**
@@ -846,7 +846,7 @@ int avc_ss_revoke(u32 ssid, u32 tsid, u1
                   u32 perms, u32 seqno)
 {
 	return avc_control(AVC_CALLBACK_REVOKE,
-			   ssid, tsid, tclass, perms, seqno, 0);
+			   ssid, tsid, tclass, perms, seqno, NULL);
 }
 
 /**
@@ -878,7 +878,7 @@ int avc_ss_reset(u32 seqno)
 			avc_node_freelist = tmp;
 			avc_cache.active_nodes--;
 		}
-		avc_cache.slots[i] = 0;
+		avc_cache.slots[i] = NULL;
 	}
 	avc_cache.lru_hint = 0;
 
@@ -890,7 +890,7 @@ int avc_ss_reset(u32 seqno)
 	for (c = avc_callbacks; c; c = c->next) {
 		if (c->events & AVC_CALLBACK_RESET) {
 			rc = c->callback(AVC_CALLBACK_RESET,
-					 0, 0, 0, 0, 0);
+					 0, 0, 0, 0, NULL);
 			if (rc)
 				goto out;
 		}
@@ -918,10 +918,10 @@ int avc_ss_set_auditallow(u32 ssid, u32 
 {
 	if (enable)
 		return avc_control(AVC_CALLBACK_AUDITALLOW_ENABLE,
-				   ssid, tsid, tclass, perms, seqno, 0);
+				   ssid, tsid, tclass, perms, seqno, NULL);
 	else
 		return avc_control(AVC_CALLBACK_AUDITALLOW_DISABLE,
-				   ssid, tsid, tclass, perms, seqno, 0);
+				   ssid, tsid, tclass, perms, seqno, NULL);
 }
 
 /**
@@ -938,10 +938,10 @@ int avc_ss_set_auditdeny(u32 ssid, u32 t
 {
 	if (enable)
 		return avc_control(AVC_CALLBACK_AUDITDENY_ENABLE,
-				   ssid, tsid, tclass, perms, seqno, 0);
+				   ssid, tsid, tclass, perms, seqno, NULL);
 	else
 		return avc_control(AVC_CALLBACK_AUDITDENY_DISABLE,
-				   ssid, tsid, tclass, perms, seqno, 0);
+				   ssid, tsid, tclass, perms, seqno, NULL);
 }
 
 /**
@@ -993,7 +993,7 @@ int avc_has_perm_noaudit(u32 ssid, u32 t
 			ae->used = 1;
 		} else {
 			avc_cache_stats_incr(AVC_ENTRY_DISCARDS);
-			ae = 0;
+			ae = NULL;
 		}
 	}
 
diff -puN security/selinux/ss/conditional.c~use-null-instead-of-integer-0-in-security-selinux security/selinux/ss/conditional.c
--- 25/security/selinux/ss/conditional.c~use-null-instead-of-integer-0-in-security-selinux	2004-07-07 12:29:26.996935856 -0700
+++ 25-akpm/security/selinux/ss/conditional.c	2004-07-07 12:29:27.007934184 -0700
@@ -217,7 +217,7 @@ int bool_isvalid(struct cond_bool_datum 
 
 int cond_read_bool(struct policydb *p, struct hashtab *h, void *fp)
 {
-	char *key = 0;
+	char *key = NULL;
 	struct cond_bool_datum *booldatum;
 	__u32 *buf, len;
 
@@ -251,7 +251,7 @@ int cond_read_bool(struct policydb *p, s
 
 	return 0;
 err:
-	cond_destroy_bool(key, booldatum, 0);
+	cond_destroy_bool(key, booldatum, NULL);
 	return -1;
 }
 
diff -puN security/selinux/ss/ebitmap.c~use-null-instead-of-integer-0-in-security-selinux security/selinux/ss/ebitmap.c
--- 25/security/selinux/ss/ebitmap.c~use-null-instead-of-integer-0-in-security-selinux	2004-07-07 12:29:26.997935704 -0700
+++ 25-akpm/security/selinux/ss/ebitmap.c	2004-07-07 12:29:27.007934184 -0700
@@ -17,7 +17,7 @@ int ebitmap_or(struct ebitmap *dst, stru
 
 	n1 = e1->node;
 	n2 = e2->node;
-	prev = 0;
+	prev = NULL;
 	while (n1 || n2) {
 		new = kmalloc(sizeof(*new), GFP_ATOMIC);
 		if (!new) {
@@ -40,7 +40,7 @@ int ebitmap_or(struct ebitmap *dst, stru
 			n2 = n2->next;
 		}
 
-		new->next = 0;
+		new->next = NULL;
 		if (prev)
 			prev->next = new;
 		else
@@ -80,7 +80,7 @@ int ebitmap_cpy(struct ebitmap *dst, str
 
 	ebitmap_init(dst);
 	n = src->node;
-	prev = 0;
+	prev = NULL;
 	while (n) {
 		new = kmalloc(sizeof(*new), GFP_ATOMIC);
 		if (!new) {
@@ -90,7 +90,7 @@ int ebitmap_cpy(struct ebitmap *dst, str
 		memset(new, 0, sizeof(*new));
 		new->startbit = n->startbit;
 		new->map = n->map;
-		new->next = 0;
+		new->next = NULL;
 		if (prev)
 			prev->next = new;
 		else
@@ -155,7 +155,7 @@ int ebitmap_set_bit(struct ebitmap *e, u
 {
 	struct ebitmap_node *n, *prev, *new;
 
-	prev = 0;
+	prev = NULL;
 	n = e->node;
 	while (n && n->startbit <= bit) {
 		if ((n->startbit + MAPSIZE) > bit) {
@@ -231,7 +231,7 @@ void ebitmap_destroy(struct ebitmap *e)
 	}
 
 	e->highbit = 0;
-	e->node = 0;
+	e->node = NULL;
 	return;
 }
 
diff -puN security/selinux/ss/mls.c~use-null-instead-of-integer-0-in-security-selinux security/selinux/ss/mls.c
--- 25/security/selinux/ss/mls.c~use-null-instead-of-integer-0-in-security-selinux	2004-07-07 12:29:26.999935400 -0700
+++ 25-akpm/security/selinux/ss/mls.c	2004-07-07 12:29:27.008934032 -0700
@@ -654,7 +654,7 @@ int cat_destroy(void *key, void *datum, 
 
 int sens_read(struct policydb *p, struct hashtab *h, void *fp)
 {
-	char *key = 0;
+	char *key = NULL;
 	struct level_datum *levdatum;
 	int rc;
 	u32 *buf, len;
@@ -707,7 +707,7 @@ bad:
 
 int cat_read(struct policydb *p, struct hashtab *h, void *fp)
 {
-	char *key = 0;
+	char *key = NULL;
 	struct cat_datum *catdatum;
 	int rc;
 	u32 *buf, len;
diff -puN security/selinux/ss/policydb.c~use-null-instead-of-integer-0-in-security-selinux security/selinux/ss/policydb.c
--- 25/security/selinux/ss/policydb.c~use-null-instead-of-integer-0-in-security-selinux	2004-07-07 12:29:27.001935096 -0700
+++ 25-akpm/security/selinux/ss/policydb.c	2004-07-07 12:29:27.009933880 -0700
@@ -99,7 +99,7 @@ static struct policydb_compat_info *poli
  */
 int roles_init(struct policydb *p)
 {
-	char *key = 0;
+	char *key = NULL;
 	int rc;
 	struct role_datum *role;
 
@@ -402,7 +402,7 @@ static int common_destroy(void *key, voi
 
 	kfree(key);
 	comdatum = datum;
-	hashtab_map(comdatum->permissions.table, perm_destroy, 0);
+	hashtab_map(comdatum->permissions.table, perm_destroy, NULL);
 	hashtab_destroy(comdatum->permissions.table);
 	kfree(datum);
 	return 0;
@@ -416,7 +416,7 @@ static int class_destroy(void *key, void
 
 	kfree(key);
 	cladatum = datum;
-	hashtab_map(cladatum->permissions.table, perm_destroy, 0);
+	hashtab_map(cladatum->permissions.table, perm_destroy, NULL);
 	hashtab_destroy(cladatum->permissions.table);
 	constraint = cladatum->constraints;
 	while (constraint) {
@@ -498,7 +498,7 @@ void policydb_destroy(struct policydb *p
 	int i;
 
 	for (i = 0; i < SYM_NUM; i++) {
-		hashtab_map(p->symtab[i].table, destroy_f[i], 0);
+		hashtab_map(p->symtab[i].table, destroy_f[i], NULL);
 		hashtab_destroy(p->symtab[i].table);
 	}
 
@@ -669,7 +669,7 @@ out:
 
 static int perm_read(struct policydb *p, struct hashtab *h, void *fp)
 {
-	char *key = 0;
+	char *key = NULL;
 	struct perm_datum *perdatum;
 	int rc;
 	u32 *buf, len;
@@ -718,7 +718,7 @@ bad:
 
 static int common_read(struct policydb *p, struct hashtab *h, void *fp)
 {
-	char *key = 0;
+	char *key = NULL;
 	struct common_datum *comdatum;
 	u32 *buf, len, nel;
 	int i, rc;
@@ -776,7 +776,7 @@ bad:
 
 static int class_read(struct policydb *p, struct hashtab *h, void *fp)
 {
-	char *key = 0;
+	char *key = NULL;
 	struct class_datum *cladatum;
 	struct constraint_node *c, *lc;
 	struct constraint_expr *e, *le;
@@ -943,7 +943,7 @@ bad:
 
 static int role_read(struct policydb *p, struct hashtab *h, void *fp)
 {
-	char *key = 0;
+	char *key = NULL;
 	struct role_datum *role;
 	int rc;
 	u32 *buf, len;
@@ -1008,7 +1008,7 @@ bad:
 
 static int type_read(struct policydb *p, struct hashtab *h, void *fp)
 {
-	char *key = 0;
+	char *key = NULL;
 	struct type_datum *typdatum;
 	int rc;
 	u32 *buf, len;
@@ -1055,7 +1055,7 @@ bad:
 
 static int user_read(struct policydb *p, struct hashtab *h, void *fp)
 {
-	char *key = 0;
+	char *key = NULL;
 	struct user_datum *usrdatum;
 	int rc;
 	u32 *buf, len;
diff -puN security/selinux/ss/services.c~use-null-instead-of-integer-0-in-security-selinux security/selinux/ss/services.c
--- 25/security/selinux/ss/services.c~use-null-instead-of-integer-0-in-security-selinux	2004-07-07 12:29:27.002934944 -0700
+++ 25-akpm/security/selinux/ss/services.c	2004-07-07 12:29:27.011933576 -0700
@@ -308,7 +308,7 @@ int security_compute_av(u32 ssid,
 			u32 requested,
 			struct av_decision *avd)
 {
-	struct context *scontext = 0, *tcontext = 0;
+	struct context *scontext = NULL, *tcontext = NULL;
 	int rc = 0;
 
 	if (!ss_initialized) {
@@ -355,7 +355,7 @@ int context_struct_to_string(struct cont
 {
 	char *scontextp;
 
-	*scontext = 0;
+	*scontext = NULL;
 	*scontext_len = 0;
 
 	/* Compute the size of the context. */
@@ -600,8 +600,8 @@ static int security_compute_sid(u32 ssid
 				u32 specified,
 				u32 *out_sid)
 {
-	struct context *scontext = 0, *tcontext = 0, newcontext;
-	struct role_trans *roletr = 0;
+	struct context *scontext = NULL, *tcontext = NULL, newcontext;
+	struct role_trans *roletr = NULL;
 	struct avtab_key avkey;
 	struct avtab_datum *avdatum;
 	struct avtab_node *node;
_
